package MT::Plugin::LightBox;
use strict;
use MT;
use MT::Plugin;

our $VERSION = '1.0';

use base qw( MT::Plugin );

@MT::Plugin::LightBox::ISA = qw( MT::Plugin );

my $plugin = new MT::Plugin::LightBox ( {
    name => 'LightBox',
    id   => 'LightBox',
    key  => 'lightbox',
    description => '<MT_TRANS phrase=\'_PLUGIN_DESCRIPTION\'>',
    author_name => 'Junnama Noda',
    author_link => 'http://junnama.alfasado.net/online/',
    version     => $VERSION,
    settings => new MT::PluginSettings ( [
        ['lb_classname', { Default => 'lightbox' }],
    ] ),
    l10n_class => 'LightBox::L10N',
} );

MT->add_plugin( $plugin );

sub init_registry {
    my $plugin = shift;
    $plugin->registry( {
        callbacks => {
            'MT::App::CMS::template_param.asset_options_image'
                => \&_asset_options_image_param,
            'MT::App::CMS::template_param.asset_insert'
                => \&_asset_insert_param,
        },
   } );
}

sub _asset_options_image_param {
    my ( $cb, $app, $param, $tmpl ) = @_;
    my $pointer_field = $tmpl->getElementById( 'link_to_popup' );
    my $nodeset = $tmpl->createElement('app:setting', { id => 'link_to_lightbox', 
    label => $plugin->translate( 'Use LightBox' ) ,
    label_class => 'no-header',
    required => 0 });
    my $innerHTML =<<MTML;
        <input type="checkbox" 
        onclick="if(this.checked){document.getElementById('create_thumbnail').checked=true;}else{
        document.getElementById('create_thumbnail').checked=false;}"
        name="lightbox" id="lightbox" value="1" <mt:if name="make_thumb">checked="checked" </mt:if>/>
        <label for="lightbox"><__trans_section component="LightBox"><__trans phrase="Use LightBox"></__trans_section></label>
MTML
    $nodeset->innerHTML( $innerHTML );
    $tmpl->insertBefore( $nodeset, $pointer_field );
}

sub _asset_insert_param {
    my ( $cb, $app, $param, $tmpl ) = @_;
    if ( $app->param('lightbox') ) {
        my $lb_classname = $plugin->get_config_value( 'lb_classname' );
        my $upload_html = $param->{ upload_html };
        $upload_html =~ s/<a/<a rel="$lb_classname"/i;
        $param->{ upload_html } = $upload_html;
    }
}

1;